/*******************************************************************************
* File Name: PGA_CL2_Bias.c  
* Version 1.60
*
* Description:
*  This file provides the source code to the API for the PGA 
*  User Module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PGA_CL2_Bias.h"

#if(PGA_CL2_Bias_CYDEV_VDDA_MV < PGA_CL2_Bias_MINIMUM_VDDA_THRESHOLD_MV)
    #include "PGA_CL2_Bias_ScBoostClk.h"
#endif /* PGA_CL2_Bias_ACLK_ENABLE */


/* Constant array for gain settings */
const uint8 PGA_CL2_Bias_GainArray[9] = { 
   (PGA_CL2_Bias_RVAL_20K   | PGA_CL2_Bias_R20_40B_40K | PGA_CL2_Bias_BIAS_LOW), /* G=1  */
   (PGA_CL2_Bias_RVAL_30K   | PGA_CL2_Bias_R20_40B_40K | PGA_CL2_Bias_BIAS_LOW), /* G=2  */
   (PGA_CL2_Bias_RVAL_40K   | PGA_CL2_Bias_R20_40B_40K | PGA_CL2_Bias_BIAS_LOW), /* G=4  */
   (PGA_CL2_Bias_RVAL_60K   | PGA_CL2_Bias_R20_40B_40K | PGA_CL2_Bias_BIAS_LOW), /* G=8  */
   (PGA_CL2_Bias_RVAL_120K  | PGA_CL2_Bias_R20_40B_40K | PGA_CL2_Bias_BIAS_LOW), /* G=16 */
   (PGA_CL2_Bias_RVAL_250K  | PGA_CL2_Bias_R20_40B_40K | PGA_CL2_Bias_BIAS_LOW), /* G=24 */
   (PGA_CL2_Bias_RVAL_250K  | PGA_CL2_Bias_R20_40B_20K | PGA_CL2_Bias_BIAS_LOW), /* G=32 */
   (PGA_CL2_Bias_RVAL_500K  | PGA_CL2_Bias_R20_40B_20K | PGA_CL2_Bias_BIAS_LOW), /* G=48 */
   (PGA_CL2_Bias_RVAL_1000K | PGA_CL2_Bias_R20_40B_20K | PGA_CL2_Bias_BIAS_LOW)  /* G=50 */
};

/* Constant array for gain compenstion settings */
const uint8 PGA_CL2_Bias_GainComp[9] = { 
   ( PGA_CL2_Bias_COMP_4P35PF  | ( PGA_CL2_Bias_REDC_00 >> 2 )), /* G=1  */
   ( PGA_CL2_Bias_COMP_4P35PF  | ( PGA_CL2_Bias_REDC_01 >> 2 )), /* G=2  */
   ( PGA_CL2_Bias_COMP_3P0PF   | ( PGA_CL2_Bias_REDC_01 >> 2 )), /* G=4  */
   ( PGA_CL2_Bias_COMP_3P0PF   | ( PGA_CL2_Bias_REDC_01 >> 2 )), /* G=8  */
   ( PGA_CL2_Bias_COMP_3P6PF   | ( PGA_CL2_Bias_REDC_01 >> 2 )), /* G=16 */
   ( PGA_CL2_Bias_COMP_3P6PF   | ( PGA_CL2_Bias_REDC_11 >> 2 )), /* G=24 */
   ( PGA_CL2_Bias_COMP_3P6PF   | ( PGA_CL2_Bias_REDC_11 >> 2 )), /* G=32 */
   ( PGA_CL2_Bias_COMP_3P6PF   | ( PGA_CL2_Bias_REDC_00 >> 2 )), /* G=48 */
   ( PGA_CL2_Bias_COMP_3P6PF   | ( PGA_CL2_Bias_REDC_00 >> 2 ))  /* G=50 */
};

uint8 PGA_CL2_Bias_initVar = 0u;


/*******************************************************************************   
* Function Name: PGA_CL2_Bias_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  PGA_CL2_Bias_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
* Reentrant:
*  No
* 
*******************************************************************************/
void PGA_CL2_Bias_Init(void) 
{
    /* Set PGA mode */
    PGA_CL2_Bias_CR0_REG = PGA_CL2_Bias_MODE_PGA;  
    
    /* Set non-inverting PGA mode  and reference mode */
    PGA_CL2_Bias_CR1_REG |= PGA_CL2_Bias_PGA_NINV;  

    /* Set default gain and ref mode */
    PGA_CL2_Bias_CR2_REG = PGA_CL2_Bias_VREF_MODE;

    /* Set gain and compensation */
    PGA_CL2_Bias_SetGain(PGA_CL2_Bias_DEFAULT_GAIN);

    /* Set power */
    PGA_CL2_Bias_SetPower(PGA_CL2_Bias_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: PGA_CL2_Bias_Enable
********************************************************************************
*
* Summary:
*  Enables the PGA block operation
*
* Parameters:
*  void
*
* Return:
*  void
*
* Reentrant:
*  No
* 
*******************************************************************************/
void PGA_CL2_Bias_Enable(void) 
{
    /* If a boost clock is required  */
    #if(PGA_CL2_Bias_CYDEV_VDDA_MV < PGA_CL2_Bias_MINIMUM_VDDA_THRESHOLD_MV)
        PGA_CL2_Bias_ACLK_PM_ACT_CFG_REG |= PGA_CL2_Bias_ACLK_ACT_PWR_EN;
        PGA_CL2_Bias_ACLK_PM_STBY_CFG_REG |= PGA_CL2_Bias_ACLK_STBY_PWR_EN;
		PGA_CL2_Bias_ScBoostClk_Enable();  /* turn on boost pump */
        PGA_CL2_Bias_BST_REG |= 0x08;
	 #endif /* PGA_CL2_Bias_ACLK_ENABLE */
   
    /* PSoC3 ES2 or early, PSoC5 ES1 */
    #if (PGA_CL2_Bias_PSOC3_ES2 || PGA_CL2_Bias_PSOC5_ES1)
        /* Enable Pump only if voltage is below threshold */
        if (PGA_CL2_Bias_CYDEV_VDDA_MV < PGA_CL2_Bias_VDDA_THRESHOLD_MV)
        {
            PGA_CL2_Bias_SC_MISC_REG |= PGA_CL2_Bias_PUMP_FORCE;
        }
        
    /* PSoC3 ES3 or later, PSoC5 ES2 or later*/
    #elif (PGA_CL2_Bias_PSOC3_ES3 || PGA_CL2_Bias_PSOC5_ES2)
        /* Enable charge Pump clock for SC block */
        PGA_CL2_Bias_PUMP_CR1_REG |= PGA_CL2_Bias_PUMP_CR1_SC_CLKSEL;
        /* Enable Pump only if voltage is below threshold */
        if (PGA_CL2_Bias_CYDEV_VDDA_MV < PGA_CL2_Bias_VDDA_THRESHOLD_MV)
        {
            PGA_CL2_Bias_SC_MISC_REG |= PGA_CL2_Bias_PUMP_FORCE;
        }
    #endif /* PGA_CL2_Bias_PSOC3_ES2 || PGA_CL2_Bias_PSOC5_ES1 */
     
    /* Enable power to the Amp in Active mode*/
    PGA_CL2_Bias_PM_ACT_CFG_REG |= PGA_CL2_Bias_ACT_PWR_EN;

    /* Enable power to the Amp in Alternative Active mode*/
    PGA_CL2_Bias_PM_STBY_CFG_REG |= PGA_CL2_Bias_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name: PGA_CL2_Bias_Start
********************************************************************************
*
* Summary:
*  The start function initializes the PGA with the default values, and sets
*  the power to the given level.  A power level of 0, is the same as executing
*  the stop function.
*
* Parameters:  
*  void
*
* Return: 
*  void 
*
* Reentrant: 
*  No
*
*******************************************************************************/
void PGA_CL2_Bias_Start(void) 
{
    if(PGA_CL2_Bias_initVar == 0u)
    {
        PGA_CL2_Bias_Init();                    
        PGA_CL2_Bias_initVar = 1u;  
    }
    
    PGA_CL2_Bias_Enable();              
}


/*******************************************************************************
* Function Name: PGA_CL2_Bias_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant: 
*  No
*
*******************************************************************************/
void PGA_CL2_Bias_Stop(void) 
{
    /* Disable pumps only if only one SC block is in use */
    if (PGA_CL2_Bias_PM_ACT_CFG_REG == PGA_CL2_Bias_ACT_PWR_EN)
    {
       PGA_CL2_Bias_SC_MISC_REG &= ~PGA_CL2_Bias_PUMP_FORCE;
    }   
    /* Disble power to the Amp in Active mode template */
    PGA_CL2_Bias_PM_ACT_CFG_REG &= ~PGA_CL2_Bias_ACT_PWR_EN;

    /* Disble power to the Amp in Alternative Active mode template */
    PGA_CL2_Bias_PM_STBY_CFG_REG &= ~PGA_CL2_Bias_STBY_PWR_EN;

    /* If a boost clock is required  */
    /* Disable SC Block boost clk control, if used (MinVdda < 2.7V) */
    #if(PGA_CL2_Bias_CYDEV_VDDA_MV < PGA_CL2_Bias_MINIMUM_VDDA_THRESHOLD_MV)
        PGA_CL2_Bias_ACLK_PM_ACT_CFG_REG &= ~PGA_CL2_Bias_ACLK_ACT_PWR_EN;
        PGA_CL2_Bias_ACLK_PM_STBY_CFG_REG &= ~PGA_CL2_Bias_ACLK_STBY_PWR_EN;
        PGA_CL2_Bias_ScBoostClk_Disable();      		
    #endif /* PGA_CL2_Bias_ACLK_ENABLE */

}


/*******************************************************************************
* Function Name: PGA_CL2_Bias_SetPower
********************************************************************************
*
* Summary:
*  Set the power of the PGA
*
* Parameters:  
*  power:  Sets power level between (0) and (3) high power
*
* Return: 
*  void
*
* Reentrant: 
*  Yes
*
*******************************************************************************/
void PGA_CL2_Bias_SetPower(uint8 power) 
{
    uint8 tmpCR;

    tmpCR = PGA_CL2_Bias_CR1_REG & ~PGA_CL2_Bias_DRIVE_MASK;
    tmpCR |= (power & PGA_CL2_Bias_DRIVE_MASK);
    PGA_CL2_Bias_CR1_REG = tmpCR;  
}


/*******************************************************************************
* Function Name: PGA_CL2_Bias_SetGain
********************************************************************************
*
* Summary:
*  This function sets values of the input and feedback resistors to set a 
*  specific gain of the amplifier.
*
* Parameters:  
*  gain:  Gain value of PGA (See header file for gain values.)
*
* Return: 
*  void 
*
* Reentrant: 
*  Yes
*
*******************************************************************************/
void PGA_CL2_Bias_SetGain(uint8 gain) 
{
    /* Only set new gain if it is a valid gain */
    if( gain <= PGA_CL2_Bias_GAIN_MAX)
    {
        /* Clear resistors, redc, and bias */
        PGA_CL2_Bias_CR2_REG &= ~(PGA_CL2_Bias_RVAL_MASK | PGA_CL2_Bias_R20_40B_MASK | 
                                PGA_CL2_Bias_REDC_MASK | PGA_CL2_Bias_BIAS_MASK );

        /* Set gain value resistors, redc comp, and bias */
        PGA_CL2_Bias_CR2_REG |= (PGA_CL2_Bias_GainArray[gain] |
                                ( (PGA_CL2_Bias_GainComp[gain] << 2 ) & PGA_CL2_Bias_REDC_MASK));
             
        /* Clear sc_comp  */
        PGA_CL2_Bias_CR1_REG &= ~PGA_CL2_Bias_COMP_MASK;
        /* Set sc_comp  */
        PGA_CL2_Bias_CR1_REG |= ( PGA_CL2_Bias_GainComp[gain] | PGA_CL2_Bias_COMP_MASK );
    }
}


/* [] END OF FILE */
